@@ -414,7 +414,7 @@ class Horde_Image_Exif_Bundled extends Horde_Image_Exif_Base
         if ($intel == 1) {
             $type = Horde_Image_Exif::intel2Moto($type);
         }
-        $this->_lookupType($type, $size);
+        list($type, $size) = $this->_lookupType($type);
 
         // 4 byte number of elements
         $count = bin2hex($in->substring(0, 4));
@@ -866,12 +866,14 @@ class Horde_Image_Exif_Bundled extends Horde_Image_Exif_Base
     }
 
     /**
+     * Look up the data type.
      *
-     * @param $type
-     * @param $size
-     * @return unknown_type
+     * @param string  The string representation of the hex type code.
+     *
+     * @return array  An array containing the string type name in the 0 index
+     *                and the integer size in the 1 index.
      */
-    protected function _lookupType(&$type, &$size)
+    protected function _lookupType($type)
     {
         switch ($type) {
         case '0001': $type = 'UBYTE'; $size = 1; break;
@@ -889,7 +891,7 @@ class Horde_Image_Exif_Bundled extends Horde_Image_Exif_Base
         default: $type = 'error:'.$type; $size = 0; break;
         }
 
-        return $type;
+        return array($type, $size);
     }
 
     public function supportedCategories()
