@@ -21,12 +21,14 @@
 class Horde_Image_Exif_Parser_Base
 {
     /**
+     * Look up the data type.
      *
-     * @param $type
-     * @param $size
-     * @return unknown_type
+     * @param string  The string representation of the hex type code.
+     *
+     * @return array  An array containing the string type name in the 0 index
+     *                and the integer size in the 1 index.
      */
-    protected function _lookupType(&$type, &$size)
+    protected function _lookupType($type)
     {
         switch($type) {
         case '0001': $type = 'UBYTE';          $size = 1; break;
@@ -43,5 +45,7 @@ class Horde_Image_Exif_Parser_Base
         case '000c': $type = 'DOUBLE';         $size = 8; break;
         default:     $type = 'error:' . $type; $size = 0; break;
         }
+
+        return array($type, $size);
     }
 }
\ No newline at end of file
