@@ -528,7 +528,7 @@ class Horde_Image_Exif_Parser_Canon extends Horde_Image_Exif_Parser_Base
             if ($intel == 1) {
                 $type = Horde_Image_Exif::intel2Moto($type);
             }
-            $this->_lookupType($type, $size);
+            list($type, $size) = $this->_lookupType($type);
 
             //4 byte count of number of data units
             $count = bin2hex(substr($block, $place, 4));
